options nodate nonumber;

** Show patient data;

proc print data=complex.patient_info(obs=20);
title 'Patient Info';
run;
ods listing close;

** Create summary information using a SAS Macro program;
options nomlogic nosymbolgen;
%macro makestat(type=sum, var=, prt=no);
%if &type = sum %then %do;
  ods output onewayfreqs=work.&var(drop=table f_&var 
                                   rename=(frequency=Count));
  proc freq data=complex.patient_info ;
    tables  &var / nocum ;
  run;
%end;
%else %if &type = means %then %do;
  ods output summary=work.&var;
  proc means data=complex.patient_info n mean std range min max ;
    var &var;
  run;
%end;

%if &prt = yes %then %do;
  ods listing;
  proc print data=work.&var;
    title "&var";
  run;
  ods listing close;
%end;
%mend makestat;
%makestat(type=means, var=age, prt=no);
%makestat(type=sum, var=gender, prt=no);
%makestat(type=means, var=lvef, prt=no);
%makestat(type=sum, var=cadn, prt=no);
%makestat(type=sum, var=cadmi, prt=no);
%makestat(type=sum, var=hypern, prt=no);
%makestat(type=sum, var=nyha, prt=no);


**  Combine all summary information so VARINFO is both "heading";
**  and categories under the heading. Then, the VALUE variable;
**  is a character variable with the extra characters;
**  like parens, etc, added.;
data agemeans(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 1 brkvar 'y';
  set age;
  varinfo = 'Age';
  value = put(age_mean, 7.2)||' '||put(age_Stddev, 8.3)||
          ' (' ||
          compress(left(put(age_Min, 2.))) ||
          ' - ' || 
          compress(left(put(age_Max, 3.))) ||
          ')';
  roword + 1;
  call symput('n',put(age_n,comma5.0));
run;

%put----> total count = &n;

data gendcnt(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 2 brkvar 'y';

  set gender;
  if _n_ = 1 then do;
    varinfo = 'Gender';
    value = ' ';
    roword + 1;
    output;
  end;
  varinfo = trim(gender);
  value = put(count, 3.)||' ('||put(percent, 6.2)||')';
  roword + 1;
  output;
run;

data lvefmeans(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 3 brkvar 'y';

  set lvef;
  varinfo = 'LVEF';
  value = put(lvef_mean, 7.2)||' '||put(lvef_Stddev, 8.3)||
          ' (' ||
          compress(left(put(lvef_Min, 2.))) ||
          ' - ' || 
          compress(left(put(lvef_Max, 3.))) ||
          ')';
  roword + 1;
run;

proc format;
  value y_n 0='No'
            1='Yes';
  value mi_stat 0='Without MI'
                1='With MI';
  value hyp_stat 0='No Hypertension'
                 1='Hypertension';
run;

data cadcnt(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 4 brkvar 'y';

  set cadn;
  if _n_ = 1 then do;
     varinfo = 'CAD(required)';
     value = ' ';
     roword + 1;
     output;
  end;
  varinfo = trim(put(cadn,y_n.));
  value = put(count, 3.)||' ('||put(percent, 6.2)||')';
  roword + 1;
  output;
run;


data micnt(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 5 brkvar 'y';

  set cadmi;
  if _n_ = 1 then do;
     varinfo = 'MI Status';
     value = ' ';
     roword + 1;
     output;
  end;

  varinfo = trim(put(cadmi,mi_stat.));
  value = put(count, 3.)||' ('||compress(put(percent, 6.2))||')';
  roword + 1;
  output;
run;



data  hypcnt(keep=grpord roword varinfo value brkvar);
   length grpord roword 8 varinfo $35 value $200;
   retain grpord 6 brkvar 'y';

   set hypern;
   if _n_ = 1 then do;
     varinfo = 'Hypertension Status';
     value = ' ';
     roword + 1;
     output;
   end;

   varinfo = trim(put(hypern,hyp_stat.));
   value = put(count, 3.)||' ('||compress(put(percent, 6.2))||')';
   roword + 1;
   output;
run;

data nyhacnt(keep=grpord roword varinfo value brkvar);
  length grpord roword 8 varinfo $35 value $200;
  retain grpord 7 brkvar 'y';

  set nyha;
  if _n_ = 1 then do;
     varinfo = 'NYHA Functional Class';
     value = ' ';
     roword + 1;
     output;
  end;
  varinfo = nyha;
  Value = put(count, 3.)||' ('||compress(put(percent, 6.2))||')';
  roword + 1;
  output;
run;

** make final data set;
data finaldata;
  set agemeans
      gendcnt
      lvefmeans
      cadcnt
      micnt
      hypcnt
      nyhacnt
      ;
run;

ods listing;
proc print data=finaldata;
  title 'what the final data looks like';
  var brkvar grpord roword varinfo value ;
run;

ods listing close;

%let style=JOURNAL;
ods listing close;
ods rtf file='complex1_demog.rtf' style=&style;
title font='Arial' h=14pt 'Using PROC REPORT';
title2 font='Arial' h=12pt bold "With &style Style";
ods escapechar='#';

proc report data=finaldata nowd noheader ls=256
    style(report)={borderwidth=6 bordercolor=black cellpadding=3
                  font_size=10pt font_face=Arial}
    style(lines)={background=white foreground=black 
                  font_weight=bold
                  font_size=14pt font_face=Arial
                  protectspecialchars=off}
    style(column)={background=white foreground=black 
                  font_size=10pt font_face=Arial
                  font_weight=medium};
  column brkvar grpord roword varinfo value;
  define brkvar / order noprint;
  define grpord / order noprint;
  define roword / order noprint;
  define varinfo /display order=data;
  define value / display
     style(column)={font_weight=medium just=right asis=on};
  compute varinfo ;
    if roword = 1 then do;
       call define(_col_,'style',
                   "style={font_weight=bold}");
    end;
    else do;
       call define(_col_,'style',
                   "style={font_weight=medium leftmargin=12pt}");
    end;
  endcomp;
  compute after grpord/
      style={cellheight=2pt font_size=2pt};
      line ' ';
  endcomp;
  compute before _page_ / style={just=center font_size=12pt};
    line "\ul{Patient Characteristics}";
    line "\ul{(N=  &n  Patients)}";
  endcomp;
  compute before brkvar / style={just=left font_size=10pt};
  ** needed brkvar so this could be in a sep table cell;
  ** and justified separately from the other 2 lines;
  ** and underlined;
    line "\ul{Patient Demographics}";
  endcomp;
run;
ods rtf close;

title;
