options nodate nonumber;

** Show partial patient data;
proc print data=complex.patient_info(obs=20);
title 'Patient Info';
run;
ods listing close;

** Create summary information using a SAS Macro program;
options nomlogic nosymbolgen;
%macro makestat(type=sum, var=, prt=no, ord=, vartitl=, maken=no);
%if &type = sum %then %do;
  ods output onewayfreqs=work.&var(drop=table f_&var 
                                   rename=(frequency=Count));
  proc freq data=complex.patient_info ;
    tables  &var / nocum ;
  run;

  data &var.cnt(keep=grpord roword varinfo value brkvar);
    length grpord roword 8 varinfo $35 value $200;
    retain grpord &ord brkvar 'y';

    set &var;
    if _n_ = 1 then do;
      varinfo = "&vartitl";
      value = ' ';
      roword + 1;
      output;
    end;

    %if &var = gender %then %do;
         varinfo = trim(gender); 
    %end;
    %else %if &var = cadn %then %do;
         varinfo = trim(put(cadn,y_n.)); 
    %end;
    %else %if &var = cadmi %then %do;
         varinfo = trim(put(cadmi,mi_stat.)); 
    %end;
    %else %if &var = hypern %then %do;
         varinfo = trim(put(hypern,hyp_stat.));
    %end;
    %else %if &var = nyha %then %do;
         varinfo = trim(nyha);
    %end;

    value = put(count, 3.)||' ('||put(percent, 6.2)||')';
    roword + 1;
    output;
  run;

  ** add count and percent data to final data set;
  proc append base=work.finaldata
              data=work.&var.cnt;
  run;

%end;
%else %if &type = means %then %do;
  ods output summary=work.&var;
  proc means data=complex.patient_info n mean std range min max ;
    var &var;
  run;

  data &var.means(keep=grpord roword varinfo value brkvar);
    length grpord roword 8 varinfo $35 value $200;
    retain grpord &ord brkvar 'y';
    set &var;
    varinfo = "&vartitl";
    value = put(&var._mean, 7.2)||' '||put(&var._Stddev, 8.3)||
            ' (' ||
            compress(left(put(&var._Min, 2.))) ||
            ' - ' || 
            compress(left(put(&var._Max, 3.))) ||
            ')';
    roword + 1;
    %if &maken = yes %then %do;
        call symput('n',put(&var._n,comma5.0));
    %end;
  run;
     
    %if &maken = yes %then %do;
       %put ----> total count = &n;
    %end;

  ** add means data to final data set;
  proc append base=work.finaldata
              data=work.&var.means;
  run;

%end;

%if &prt = yes %then %do;
  ods listing;
  proc print data=work.&var;
    title "&var";
  run;
  ods listing close;
%end;

%mend makestat;

** create formats;
** these could also be permanently assigned;
proc format;
  value y_n 0='No'
            1='Yes';
  value mi_stat 0='Without MI'
                1='With MI';
  value hyp_stat 0='No Hypertension'
                 1='Hypertension';
run;

** Perform housekeeping and get rid of prior version of Finaldata;
proc datasets library=work nofs nolist;
  delete finaldata;
run;
quit;

** Create Demographic Info for Each Variable;
** TYPE is the type of summary MEANS or SUM (count and percent);
** VAR is the variable to be used.;
** ORD macro variable is order you want the variable to appear;
** on the final report.;
** VARTITL is the title for the Variable.;
** MAKEN is the flag for whether '&N' should be created 
**       -- default maken=no;
** PRT is the flag for printing the summary info
**       -- default prt=no;
%makestat(type=means, var=age, ord=1, vartitl=Age, maken=yes);
%makestat(type=sum, var=gender, ord=2, vartitl=Gender);
%makestat(type=means, var=lvef, ord=3, vartitl=LVEF);
%makestat(type=sum, var=cadn, ord=4, vartitl=%str(CAD(Required)));
%makestat(type=sum, var=cadmi, ord=5, vartitl=MI Status);
%makestat(type=sum, var=hypern,ord=6, vartitl=Hypertension Status);
%makestat(type=sum, var=nyha, ord=7, vartitl=NYHA Functional Class);

ods listing;
proc freq data=finaldata;
  title 'Checking Final Data';
  tables grpord brkvar;
run;

proc print data=finaldata;
  title 'What the Final Data Looks Like';
  var brkvar grpord roword varinfo value ;
run;

ods listing close;

** proc report solution does not need custom table template;
** OR custom style template...just note the way that I;
** create an output data set called for_thomas and then;
** print that report with PROC REPORT and use style=overrides;
** to do everything you need;
** INCLUDING the added advantage of using RTF control;
** string \ul to underline text strings;

%let style=RTF;
ods listing close;
ods rtf file='complex1_demog_macro.rtf' style=&style;
title font='Arial' h=14pt 'Using PROC REPORT';
title2 font='Arial' h=12pt bold "With &style Style";

ods escapechar='#';

proc report data=finaldata nowd noheader ls=256
    style(report)={borderwidth=3 bordercolor=black 
                  cellpadding=3
                  font_size=10pt font_face=Arial}
    style(lines)={background=white foreground=black 
                  font_weight=bold
                  font_size=14pt font_face=Arial
                  protectspecialchars=off}
    style(column)={background=white foreground=black 
                  font_size=10pt font_face=Arial
                  font_weight=medium};
  column brkvar grpord roword varinfo value;
  define brkvar / order noprint;
  define grpord / order noprint;
  define roword / order noprint;
  define varinfo /display order=data;
  define value / display
     style(column)={font_weight=medium just=right asis=on};
  compute varinfo ;
    if roword = 1 then do;
       call define(_col_,'style',
                   "style={font_weight=bold}");
    end;
    else do;
       call define(_col_,'style',
                   "style={font_weight=medium leftmargin=12pt}");
    end;
  endcomp;
  compute after grpord/
      style={cellheight=2pt font_size=2pt};
      line ' ';
  endcomp;
  compute before _page_ / style={just=center font_size=12pt};
    line "\ul{Patient Characteristics}";
    line "\ul{(N=  &n  Patients)}";
  endcomp;
  compute before brkvar / style={just=left font_size=10pt};
  ** needed brkvar so this could be in a sep table cell;
  ** and justified separately from the other 2 lines;
  ** and underlined;
    line "\ul{Patient Demographics}";
  endcomp;
run;
ods rtf close;

title;
